def Suma (a,b):
    return a+b
def Restar(a,b):
    return a-b
def Multiplicar(a,b):
    return a*b
def Dividir(a,b):
    return a/b
def hfun():
    print("Tengo las siguientes Funciones :")
    print("Suma")
    print("Restar")
    print("Multiplicar")
    print("Dividir")
